ApplePayParamsPatterns extension

Adds pattern-matching-related methods to ApplePayParams.

on

Methods

map<TResult extends Object?>(TResult $default(_ApplePayParams value)) → TResult

Available on ApplePayParams, provided by the ApplePayParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ApplePayParams value)?) → TResult?

Available on ApplePayParams, provided by the ApplePayParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ApplePayParams value)?, {required TResult orElse()}) → TResult

Available on ApplePayParams, provided by the ApplePayParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String merchantCountryCode, String currencyCode, List<String>? additionalEnabledNetworks, List<ApplePayCartSummaryItem> cartItems, List<ApplePayContactFieldsType>? requiredShippingAddressFields, List<ApplePayContactFieldsType>? requiredBillingContactFields, List<ApplePayShippingMethod>? shippingMethods, List<ApplePayMerchantCapability>? merchantCapabilities, ApplePayShippingType? shippingType, List<String>? supportedCountries, bool? supportsCouponCode, String? couponCode, PaymentRequestType? request)?, {required TResult orElse()}) → TResult

Available on ApplePayParams, provided by the ApplePayParamsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String merchantCountryCode, String currencyCode, List<String>? additionalEnabledNetworks, List<ApplePayCartSummaryItem> cartItems, List<ApplePayContactFieldsType>? requiredShippingAddressFields, List<ApplePayContactFieldsType>? requiredBillingContactFields, List<ApplePayShippingMethod>? shippingMethods, List<ApplePayMerchantCapability>? merchantCapabilities, ApplePayShippingType? shippingType, List<String>? supportedCountries, bool? supportsCouponCode, String? couponCode, PaymentRequestType? request)) → TResult

Available on ApplePayParams, provided by the ApplePayParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String merchantCountryCode, String currencyCode, List<String>? additionalEnabledNetworks, List<ApplePayCartSummaryItem> cartItems, List<ApplePayContactFieldsType>? requiredShippingAddressFields, List<ApplePayContactFieldsType>? requiredBillingContactFields, List<ApplePayShippingMethod>? shippingMethods, List<ApplePayMerchantCapability>? merchantCapabilities, ApplePayShippingType? shippingType, List<String>? supportedCountries, bool? supportsCouponCode, String? couponCode, PaymentRequestType? request)?) → TResult?

Available on ApplePayParams, provided by the ApplePayParamsPatterns extension

A variant of when that fallback to returning null