ApplePayPostalAddress class abstract

Postal address data for Apple pay

Available extensions
Annotations
  • @freezed

Constructors

ApplePayPostalAddress({String? city, String? country, String? postalCode, String? state, String? street, String? isoCountryCode, String? subAdministrativeArea, String? subLocality})
const
factory
ApplePayPostalAddress.fromJson(Map<String, dynamic> json)
factory

Properties

city String?
no setterinherited
copyWith → $ApplePayPostalAddressCopyWith<ApplePayPostalAddress>
Create a copy of ApplePayPostalAddress with the given fields replaced by the non-null parameter values.
no setterinherited
country String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isoCountryCode String?
no setterinherited
postalCode String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
no setterinherited
street String?
no setterinherited
subAdministrativeArea String?
no setterinherited
subLocality String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ApplePayPostalAddress value)) → TResult

Available on ApplePayPostalAddress, provided by the ApplePayPostalAddressPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ApplePayPostalAddress value)?) → TResult?

Available on ApplePayPostalAddress, provided by the ApplePayPostalAddressPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ApplePayPostalAddress value)?, {required TResult orElse()}) → TResult

Available on ApplePayPostalAddress, provided by the ApplePayPostalAddressPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? city, String? country, String? postalCode, String? state, String? street, String? isoCountryCode, String? subAdministrativeArea, String? subLocality)?, {required TResult orElse()}) → TResult

Available on ApplePayPostalAddress, provided by the ApplePayPostalAddressPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ApplePayPostalAddress to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? city, String? country, String? postalCode, String? state, String? street, String? isoCountryCode, String? subAdministrativeArea, String? subLocality)) → TResult

Available on ApplePayPostalAddress, provided by the ApplePayPostalAddressPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? city, String? country, String? postalCode, String? state, String? street, String? isoCountryCode, String? subAdministrativeArea, String? subLocality)?) → TResult?

Available on ApplePayPostalAddress, provided by the ApplePayPostalAddressPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited