CardStyle class abstract
Styiling information for the cardfield.
- Available extensions
- Annotations
-
- @freezed
Constructors
- CardStyle({int? borderWidth, @JsonKey.new(toJson: ColorKey.toJson, fromJson: ColorKey.fromJson) Color? backgroundColor, @JsonKey.new(toJson: ColorKey.toJson, fromJson: ColorKey.fromJson) Color? borderColor, int? borderRadius, @JsonKey.new(toJson: ColorKey.toJson, fromJson: ColorKey.fromJson) Color? cursorColor, @JsonKey.new(toJson: ColorKey.toJson, fromJson: ColorKey.fromJson) Color? textColor, int? fontSize, String? fontFamily, @JsonKey.new(toJson: ColorKey.toJson, fromJson: ColorKey.fromJson) Color? textErrorColor, @JsonKey.new(toJson: ColorKey.toJson, fromJson: ColorKey.fromJson) Color? placeholderColor})
-
factory
-
CardStyle.fromJson(Map<
String, dynamic> json) -
factory
Properties
- backgroundColor → Color?
-
no setterinherited
- borderColor → Color?
-
no setterinherited
- borderRadius → int?
-
Borderradius that can give the Cardfield rounded corners.
no setterinherited
- borderWidth → int?
-
Width for the border.
no setterinherited
-
copyWith
→ $CardStyleCopyWith<
CardStyle> -
Create a copy of CardStyle
with the given fields replaced by the non-null parameter values.
no setterinherited
- cursorColor → Color?
-
no setterinherited
- fontFamily → String?
-
Font family
no setterinherited
- fontSize → int?
-
Font size.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- placeholderColor → Color?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color?
-
no setterinherited
- textErrorColor → Color?
-
Color of the input in case incorrect data is entered.
no setterinherited
Methods
-
apply(
CardStyle? style) → CardStyle -
map<
TResult extends Object?> (TResult $default(_CardStyleConstructor value)) → TResult -
Available on CardStyle, provided by the CardStylePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CardStyleConstructor value)?) → TResult? -
Available on CardStyle, provided by the CardStylePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CardStyleConstructor value)?, {required TResult orElse()}) → TResult -
Available on CardStyle, provided by the CardStylePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int? borderWidth, Color? backgroundColor, Color? borderColor, int? borderRadius, Color? cursorColor, Color? textColor, int? fontSize, String? fontFamily, Color? textErrorColor, Color? placeholderColor)?, {required TResult orElse()}) → TResult -
Available on CardStyle, provided by the CardStylePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CardStyle to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int? borderWidth, Color? backgroundColor, Color? borderColor, int? borderRadius, Color? cursorColor, Color? textColor, int? fontSize, String? fontFamily, Color? textErrorColor, Color? placeholderColor)) → TResult -
Available on CardStyle, provided by the CardStylePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int? borderWidth, Color? backgroundColor, Color? borderColor, int? borderRadius, Color? cursorColor, Color? textColor, int? fontSize, String? fontFamily, Color? textErrorColor, Color? placeholderColor)?) → TResult? -
Available on CardStyle, provided by the CardStylePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited