CreateTokenParams class abstract

parameters that are used to create a token.

At this moment only card tokens are supported.

Available extensions
Annotations
  • @freezed

Constructors

CreateTokenParams({@Default.new(TokenType.Card) TokenType type, String? name, Address? address})
const
factory
CreateTokenParams.bankAccount({required BankAccountTokenParams params})
const
factory
CreateTokenParams.card({required CardTokenParams params})
const
factory
CreateTokenParams.fromJson(Map<String, dynamic> json)
factory
CreateTokenParams.pii({required PIITokenParams params})
Creates a single-use token that represents the details of personally identifiable information (PII).
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CreateTokenParamsLegacy value), {required TResult card(_CreateTokenParamsCard value), required TResult bankAccount(_CreateTokenParamsBankAccount value), required TResult pii(_CreateTokenParamsPII value)}) → TResult

Available on CreateTokenParams, provided by the CreateTokenParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CreateTokenParamsLegacy value)?, {TResult? card(_CreateTokenParamsCard value)?, TResult? bankAccount(_CreateTokenParamsBankAccount value)?, TResult? pii(_CreateTokenParamsPII value)?}) → TResult?

Available on CreateTokenParams, provided by the CreateTokenParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CreateTokenParamsLegacy value)?, {TResult card(_CreateTokenParamsCard value)?, TResult bankAccount(_CreateTokenParamsBankAccount value)?, TResult pii(_CreateTokenParamsPII value)?, required TResult orElse()}) → TResult

Available on CreateTokenParams, provided by the CreateTokenParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(TokenType type, String? name, Address? address)?, {TResult card(CardTokenParams params)?, TResult bankAccount(BankAccountTokenParams params)?, TResult pii(PIITokenParams params)?, required TResult orElse()}) → TResult

Available on CreateTokenParams, provided by the CreateTokenParamsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CreateTokenParams to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(TokenType type, String? name, Address? address), {required TResult card(CardTokenParams params), required TResult bankAccount(BankAccountTokenParams params), required TResult pii(PIITokenParams params)}) → TResult

Available on CreateTokenParams, provided by the CreateTokenParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(TokenType type, String? name, Address? address)?, {TResult? card(CardTokenParams params)?, TResult? bankAccount(BankAccountTokenParams params)?, TResult? pii(PIITokenParams params)?}) → TResult?

Available on CreateTokenParams, provided by the CreateTokenParamsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited