CustomPaymentMethodConfiguration class abstract

Configuration for custom payment methods in PaymentSheet.

Available extensions
Annotations
  • @freezed

Constructors

CustomPaymentMethodConfiguration({@JsonKey.new(name: 'customPaymentMethods') required List<CustomPaymentMethod> customPaymentMethods, @JsonKey.new(includeFromJson: false, includeToJson: false) ConfirmCustomPaymentMethodCallback? confirmCustomPaymentMethodCallback})
const
factory
CustomPaymentMethodConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

confirmCustomPaymentMethodCallback ConfirmCustomPaymentMethodCallback?
Callback function to handle custom payment method confirmation
no setterinherited
copyWith → $CustomPaymentMethodConfigurationCopyWith<CustomPaymentMethodConfiguration>
Create a copy of CustomPaymentMethodConfiguration with the given fields replaced by the non-null parameter values.
no setterinherited
customPaymentMethods List<CustomPaymentMethod>
Array of custom payment methods to display in the Payment Sheet
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CustomPaymentMethodConfiguration value)) → TResult

Available on CustomPaymentMethodConfiguration, provided by the CustomPaymentMethodConfigurationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CustomPaymentMethodConfiguration value)?) → TResult?

Available on CustomPaymentMethodConfiguration, provided by the CustomPaymentMethodConfigurationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CustomPaymentMethodConfiguration value)?, {required TResult orElse()}) → TResult

Available on CustomPaymentMethodConfiguration, provided by the CustomPaymentMethodConfigurationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<CustomPaymentMethod> customPaymentMethods, ConfirmCustomPaymentMethodCallback? confirmCustomPaymentMethodCallback)?, {required TResult orElse()}) → TResult

Available on CustomPaymentMethodConfiguration, provided by the CustomPaymentMethodConfigurationPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CustomPaymentMethodConfiguration to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<CustomPaymentMethod> customPaymentMethods, ConfirmCustomPaymentMethodCallback? confirmCustomPaymentMethodCallback)) → TResult

Available on CustomPaymentMethodConfiguration, provided by the CustomPaymentMethodConfigurationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<CustomPaymentMethod> customPaymentMethods, ConfirmCustomPaymentMethodCallback? confirmCustomPaymentMethodCallback)?) → TResult?

Available on CustomPaymentMethodConfiguration, provided by the CustomPaymentMethodConfigurationPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited