PlatformPaySheetUpdateParamsPatterns extension

Adds pattern-matching-related methods to PlatformPaySheetUpdateParams.

on

Methods

map<TResult extends Object?>({required TResult applePay(_PlatformPaySheetUpdateParams value)}) → TResult

Available on PlatformPaySheetUpdateParams, provided by the PlatformPaySheetUpdateParamsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? applePay(_PlatformPaySheetUpdateParams value)?}) → TResult?

Available on PlatformPaySheetUpdateParams, provided by the PlatformPaySheetUpdateParamsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult applePay(_PlatformPaySheetUpdateParams value)?, required TResult orElse()}) → TResult

Available on PlatformPaySheetUpdateParams, provided by the PlatformPaySheetUpdateParamsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult applePay(List<ApplePayCartSummaryItem> summaryItems, List<ApplePayShippingMethod> shippingMethods, List<ApplePaySheetError>? errors)?, required TResult orElse()}) → TResult

Available on PlatformPaySheetUpdateParams, provided by the PlatformPaySheetUpdateParamsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>({required TResult applePay(List<ApplePayCartSummaryItem> summaryItems, List<ApplePayShippingMethod> shippingMethods, List<ApplePaySheetError>? errors)}) → TResult

Available on PlatformPaySheetUpdateParams, provided by the PlatformPaySheetUpdateParamsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? applePay(List<ApplePayCartSummaryItem> summaryItems, List<ApplePayShippingMethod> shippingMethods, List<ApplePaySheetError>? errors)?}) → TResult?

Available on PlatformPaySheetUpdateParams, provided by the PlatformPaySheetUpdateParamsPatterns extension

A variant of when that fallback to returning null