ApplePayMultiMerchant constructor
const
ApplePayMultiMerchant({})
Implementation
@JsonSerializable(explicitToJson: true)
const factory ApplePayMultiMerchant({
/// The apple pay merchant identifier
required String merchantIdentifier,
/// External identifier for the merchant
required String externalIdentifier,
/// The merchant display name Apple pay associates with the payment token
required String merchantName,
/// The merchant top level domain Apple Pay associates with teh payment token
String? merchantDomain,
/// Amount to authorize for the payment token
required String amount,
}) = _ApplePayMultiMerchant;