CardData constructor
const
CardData({})
Implementation
@JsonSerializable(explicitToJson: true)
const factory CardData({
/// Unique identifier
String? id,
/// The brand associated to the card e.g. (visa, amex).
required String brand,
/// Two letter iso code.
String? country,
/// The three letter ISO 4217 code for the currency.
String? currency,
/// four digit number representing the year of expiry of the card.
int? expYear,
/// two digit number representing the month of expire of the card.
int? expMonth,
/// Fullname of the cardholder
String? name,
/// card funding type e.g. (credit, debit).
String? funding,
/// last four digits of the card.
String? last4,
/// Address of the cardholder
Address? address,
}) = _CardData;