FinancialConnectionAccount constructor
const
FinancialConnectionAccount({
- required String id,
- required bool livemode,
- String? displayName,
- required AccountStatus status,
- required String institutionName,
- String? last4,
- required int created,
- AccountBalance? balance,
- BalanceRefresh? balanceRefresh,
- required AccountCategory category,
- required AccountSubcategory subcategory,
- List<
AccountPermission> ? permissions, - required List<
FinancialConnectionsPaymentMethodType> supportedPaymentMethodTypes,
Implementation
@JsonSerializable(explicitToJson: true)
const factory FinancialConnectionAccount({
/// Unique id for this Financial connection account.
required String id,
/// Has the value true if the object exist in livemode.
required bool livemode,
/// display name of the account.
String? displayName,
/// The current status of the account.
required AccountStatus status,
/// The name of the financial institution.
required String institutionName,
/// Last4 of the account number.
String? last4,
/// Unix timestamp in milliseconds of the date this account was created.
required int created,
/// The balance of the account
AccountBalance? balance,
/// The last balance refresh.
BalanceRefresh? balanceRefresh,
/// The category of this account
required AccountCategory category,
/// The subcategory of this account,
required AccountSubcategory subcategory,
/// Permissions requested for accounts collected during this session.
List<AccountPermission>? permissions,
/// Support payment method types for this account.
required List<FinancialConnectionsPaymentMethodType>
supportedPaymentMethodTypes,
}) = _FinancialConnectionAccount;