IntentConfiguration class
Properties
-
confirmHandler
→ ConfirmHandler?
-
Called when the customer confirms payment. Your implementation should create
a payment intent or setupintent on your server and call the intent creation callback with its client secret or an error if one occurred.
no setterinherited
-
copyWith
→ $IntentConfigurationCopyWith<IntentConfiguration>
-
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
mode
→ IntentMode
-
Data related to the future payment intent
no setterinherited
-
paymentMethodTypes
→ List<String>?
-
The list of payment method types that the customer can use in the payment sheet.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited