IntentConfiguration constructor
const
IntentConfiguration({
- required IntentMode mode,
- List<
String> ? paymentMethodTypes, - @JsonKey.new(includeFromJson: false, includeToJson: false) ConfirmHandler? confirmHandler,
Implementation
@JsonSerializable(explicitToJson: true)
const factory IntentConfiguration({
/// Data related to the future payment intent
required IntentMode mode,
/// The list of payment method types that the customer can use in the payment sheet.
///
/// If not set, the payment sheet will display all the payment methods enabled in your Stripe dashboard.
List<String>? paymentMethodTypes,
/// Called when the customer confirms payment. Your implementation should create
/// a payment intent or setupintent on your server and call the intent creation callback with its client secret or an error if one occurred.
@JsonKey(includeFromJson: false, includeToJson: false)
ConfirmHandler? confirmHandler,
/// Confirm handler
}) = _IntentConfiguration;