PaymentMethod class
Representation of the payment instruments. See https://stripe.com/docs/payments/payment-methods for more info.
- Annotations
-
- @freezed
Constructors
- PaymentMethod({required String id, required bool livemode, required String paymentMethodType, required BillingDetails billingDetails, required Card card, required SepaDebit sepaDebit, required BacsDebit bacsDebit, required AuBecsDebit auBecsDebit, required Sofort sofort, required Ideal ideal, required Fpx fpx, required Upi upi, required UsBankAccount usBankAccount, String? customerId})
-
constfactory
-
PaymentMethod.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auBecsDebit → AuBecsDebit
-
Containing additional data in case paymentmethod type is Aubecs debit.
no setterinherited
- bacsDebit → BacsDebit
-
Containing additional data in case paymentmethod type is Bacs debit.
no setterinherited
- billingDetails → BillingDetails
-
Billing information related to the payment method.
no setterinherited
- card → Card
-
Containing additional data in case paymentmethod type is card.
no setterinherited
-
copyWith
→ $PaymentMethodCopyWith<
PaymentMethod> -
no setterinherited
- customerId → String?
-
Id related to the customer to which this paymentmethod has been saved.
no setterinherited
- fpx → Fpx
-
Containing additional data in case paymentmethod type is FPX.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier.
no setterinherited
- ideal → Ideal
-
Containing additional data in case paymentmethod type is Ideal.
no setterinherited
- livemode → bool
-
Whether or not the object exists in livemode.
no setterinherited
- paymentMethodType → String
-
The type of the paymentmethod.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sepaDebit → SepaDebit
-
Containing additional data in case paymentmethod type is sepa.
no setterinherited
- sofort → Sofort
-
Containing additional data in case paymentmethod type is sofort.
no setterinherited
- upi → Upi
-
Containing additional data in case paymentmethod type is UPI.
no setterinherited
- usBankAccount → UsBankAccount
-
Containing additional data in case paymentmethod type is UPI.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited