confirmPayment property
Flag that determines whether or not to present payment options or directly goes to confirm payment.
When value is false make sure SetupPaymentSheetParameters.customFlow
is set to true when initializing the payment sheet.
If value is set to true SetupPaymentSheetParameters.customFlow
has to be set to false when initializing the payment sheet.
Implementation
bool get confirmPayment => throw _privateConstructorUsedError;